@@ -38,14 +38,14 @@ skfmm.extension_velocities(phi, speed, dx=1.0, self_test=False,
   extension velocity and d is the signed distance function.
 
 
-:Copyright: Copyright 2017 The scikit-fmm team.
+:Copyright: Copyright 2022 The scikit-fmm team.
 :License: BSD-style license. See LICENSE.txt in the source directory.
 
 """
 
 from __future__ import print_function
 
-__version__ = "2019.1.30"
+__version__ = "2022.08.15"
 __docformat__ = 'restructuredtext'
 
 from .pfmm import distance, travel_time, extension_velocities
@@ -858,14 +858,34 @@ def testing():
     ...                   [ 1.   ,  1.   ,  1.   ,  1.   ,  1.   ,  1.   ,  1.   ],
     ...                   [ 1.   ,  1.   ,  1.   ,  1.   ,  1.   ,  1.   ,  1.   ]])
     >>> assert not travel_time(phi,speed)[0][3] == 0
-    Traceback (most recent call last):
-      File "/usr/lib/python2.7/doctest.py", line 1315, in __run
-        compileflags, 1) in test.globs
-      File "<doctest skfmm.testing[347]>", line 1, in <module>
-        assert not travel_time(phi,speed)[0][3] == 0
-      File "skfmm/pfmm.py", line 173, in travel_time
-        int(self_test), TRAVEL_TIME, order, narrow, periodic)
-    RuntimeError: Negative discriminant in time marcher quadratic.
+
+    >>> phi = np.array([[1, -1, -1],
+    ...                 [0,  0, -1],
+    ...                 [0,  0,  1]])
+    >>> value = 0.01
+    >>> speed = np.array([[ 1, value, 0.1],
+    ...                   [ 0, 0,     1. ],
+    ...                  [ 0, 0,     1. ]])
+    >>> phi = np.ma.MaskedArray(phi, phi==0)
+    >>> tt = travel_time(phi,speed)
+    >>> tt.fill_value=0
+    >>> np.testing.assert_allclose(tt.data, ((0.5, 50, 7.5),
+    ...                                      (0,    0, 0.5),
+    ...                                      (0,    0, 0.5)))
+
+    This is from Pull Request #57:
+
+    >>> a = np.array([[[600,  399,  641], [607,  605,  796], [602,  641,  797], [602,  658,  814]], [[272,   -1,  398], [208,  282,  539], [209,  285,  513], [208,  298,  519]], [[-19,   51,  307], [-191,   2,  403], [-171,   5,  325], [-172,   3,  318]]])
+
+    >>> d = distance(a)
+    >>> assert not (d==0).any()
+
+    A 2D version of this bug was also discovered
+
+    >>> a = np.array([[399,  -1, 51,   10.0], [605, 282,  2,   -3], [641, 285,  5, -100], [658, 298,  3,   -3]])
+    >>> d = distance(a)
+    >>> assert not (d==0).any()
+
     """
 
 def test(verbose=None):
